@@ -39,11 +39,10 @@ typedef struct _MainApp
     GObject parent_struct;
     GtkWidget *window;
     GtkWidget *entry;
-    GtkWidget *actionbar, *textbar;
+    GtkWidget *textbar;
     GtkWidget *preview_label;
     GtkWidget *fontpicker;
     GtkWidget *chartable;
-    gboolean insert_at_end;
     GList *buttons;
     GtkStyle *btnstyle;
     GConfClient *conf;
@@ -64,5 +63,6 @@ void main_app_destroy (MainApp *obj);
 gboolean check_gail(GtkWidget *widget);
 void add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc);
 void add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType type);
+void edit_menu_set_sensitivity (gboolean flag);
 
 #endif /* _INTERFACE_H_ */
