@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.37 2002/06/01 21:32:46 gman Exp $ */
+/* $Id: gdict-applet.c,v 1.38 2002/06/03 20:40:13 gman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -134,8 +134,7 @@ button_press_hack (GtkWidget *w, GdkEventButton *event, gpointer data)
     GtkWidget *applet = GTK_WIDGET (data);
     
     if (event->button == 3 || event->button == 2) {
-	event->window = applet->window;
-	gtk_main_do_event ((GdkEvent *) event);
+	gtk_propagate_event (applet, (GdkEvent *) event);
 
 	return TRUE;
     }
