@@ -42,13 +42,6 @@ static GtkWidget *toplevel = NULL;
 /* Only needed if more then one device exists */
 static GList *valid_devices = NULL;
 
-enum
-{
-  GFLOPPY_FORMAT,
-  GFLOPPY_CLOSE,
-  GFLOPPY_HELP
-};
-
 static void
 devices_option_activated (GtkWidget *menu_item, gchar *device)
 {
@@ -271,7 +264,7 @@ set_floppy_extended_device (void)
 }
 
 gint
-on_toplevel_delete_event (GtkWidget *w, GdkEventAny *e, gpointer data)
+on_toplevel_delete_event (GtkWidget *w, GdkEventKey *e)
 {
 	toplevel = NULL;
 	return TRUE;
@@ -286,6 +279,7 @@ main (int argc, char *argv[])
 	GtkWidget *icon;
 	GtkWidget *quick_format_button;
 	GtkWidget *device_combo;
+	gchar *image;
 	gint button;
 
 	struct poptOption gfloppy_opts[] = {
@@ -307,7 +301,13 @@ main (int argc, char *argv[])
                             GNOME_PARAM_POPT_FLAGS, 0,
                             GNOME_PARAM_APP_DATADIR,DATADIR,NULL);
 	/* FIXME: get the right icon */
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/mc/i-floppy.png");
+	image = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
+                                           "document-icons/i-floppy.png", TRUE, NULL);
+
+	
+	gnome_window_icon_set_default_from_file (image);
+	g_free (image);
+
 	init_commands ();
 
 	/* Now we can set up glade */
@@ -342,10 +342,10 @@ main (int argc, char *argv[])
 		GtkWidget *density_option;
 		GtkWidget *dialog;
 
-		if (button == GFLOPPY_CLOSE) 
+		if (button == GTK_RESPONSE_CLOSE) 
 			break;
 
-		if (button == GFLOPPY_HELP) {
+		if (button == GTK_RESPONSE_HELP) {
 			GError *error;
 
 			error = NULL;
